% DEBPIC(1) Version 1.0 | General Commands Manual 

# NAME

**debpic** — DEbian Build Package In Container

# DESCRIPTION

debpic lets you build Debian packages in an isolated Docker environment.  

The environment is composed from:  
* The [Debian stable docker image](https://hub.docker.com/_/debian/) (or whichever distribution is specified with the --distribution option).  
* Build dependencies described in the Build-Depends section of ``./debian/control``  
* Any additional developer tools described in `./developer-packages.txt`.  
* Any debian packages (.debs) placed in `./local_packages/`.  

# Options

**-h**, **--help**

: Prints brief usage information.

**-nc**, **--no-cache**

: Do not use cache when building the image.

-**s** \<SOURCES\>, **--sources** \<SOURCES\>

: Select a sources file stored at /etc/debpic/sources.list.d/\<SOURCE\>.list.

**-d** \<DISTRIBUTION\>, **--distribution** \<DISTRIBUTION\>  

: Select a linux distribution for the docker parent image (e.g.debian:11).

**-i**, **--interactive**  

: Open an interactive terminal to the container.

**-di**, **--delete-images**  

: Delete all build environment images generated by this tool.

**-dst** \<DESTINATION\>, **--destination** \<DESTINATION\>

: Destination directory to place built packages in. If not supplied ./built_packages is used.

# ENVIRONMENT

**DEB_BUILD_OPTIONS**

: This environment variable on the host is passed through to the container at run time.

# FILES

_/etc/debpic/sources.list.d/*.sources_

: This is where debpic stores the list of APT data sources that can be used in the build container. The contents of \<SOURCE\>.source file is copied to `/etc/apt/sources.list.d/debpic.sources` within the container before any build dependencies are selected. The choice of which file is selected can be controlled using the `--sources` option..


_/etc/debpic/sources.list.d/default.sources_

: When the `--sources` option is not supplied, debpic defaults to using default.sources. This is helpful is you have a private apt repository that you often use and you don't want to have specify `--sources` on every build. If this file doesn't exist then no additional sources will be configured.


_~/.config/debpic/debpic.conf_  

: User configuration file using YAML to store the same options available on the command line.

_/usr/share/debpic/Dockerfile_

: This is the dockerfile used to generate the container which the build is performed in. If you want to use other tools (such as Jenkins or VSCode) in the same containerised environment you can point them to this Dockerfile.
See documentation on how to use with [Jenkins](https://github.com/aidan-gallagher/debpic/blob/main/debpic/Documentation/using-with-jenkins.md) and [VSCode](https://github.com/aidan-gallagher/debpic/blob/main/debpic/Documentation/using-with-vscode.md).

# Examples
### Building a package
1 - Clone the repository you want to build
```
$ https://salsa.debian.org/apt-team/apt.git
```
2 - Run debpic
```
$ debpic
```
3 - Find your newly created debian packages
```
$ ls ./built_packages
```
### Running a command inside the container

```
$ debpic '<your_command_to_run>'
```
```
$ debpic 'echo Hi I'm inside the container. See the output of whoami command; whoami'
```
### Selecting sources
1 - Write apt source in deb822 format to a file in /etc/debpic/sources.list.d/. For example /etc/debpic/sources.list.d/unstable.sources
```
Enabled: Yes
Types: deb
URIs: http://my_private_apt_repo/Tools/Debian11/
Suites: ./
Trusted: yes"
```
2 - Pass the filename (without the suffix) to --sources when calling debpic
```
debpic --sources unstable
```
For more information see [using additional sources](https://github.com/aidan-gallagher/debpic/blob/main/debpic/Documentation/using-additional-sources.md).

### Install local packages
Place local debian packages (.debs) in `./local_packages/` then build as normal and they will be installed in the container.

### Install optional developer packages
Create file `./developer-packages.txt` with list of packages to be installed within the container.

# NOTES

### Git Ignore
You likely want to add the generated `built_packages` to your global git ignore file.
```
$ echo built_packages >> ~/.config/git/ignore
```

# BUGS

See GitHub Issues: https://github.com/aidan-gallagher/debpic/issues

# HOMEPAGE

https://github.com/aidan-gallagher/debpic

# AUTHOR

Aidan Gallagher <aidgal2@gmail.com>

# SEE ALSO

**docker**(1), **dpkg-buildpackage**(1), **sources.list**(5)

